﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Foundation;
using SQLite;
using UIKit;

namespace NativeiOS
{
    public class DataFormDataBase
    {
        static readonly Lazy<SQLiteAsyncConnection> lazyInitializer = new Lazy<SQLiteAsyncConnection>(() =>
        {
            return new SQLiteAsyncConnection(Constants.DatabasePath, Constants.Flags);
        });

        static SQLiteAsyncConnection Database => lazyInitializer.Value;
        static bool initialized = false;

        public DataFormDataBase()
        {
            InitializeAsync().SafeFireAndForget(false);
        }

        async Task InitializeAsync()
        {
            if (!initialized)
            {
                if (!Database.TableMappings.Any(m => m.MappedType.Name == typeof(DataFormModel).Name))
                {
                    await Database.CreateTablesAsync(CreateFlags.None, typeof(DataFormModel)).ConfigureAwait(false);
                    initialized = true;
                }
            }
        }

        public Task<List<DataFormModel>> GetItemsAsync()
        {
            return Database.Table<DataFormModel>().ToListAsync();
        }

        public Task<DataFormModel> GetItemAsync(string name)
        {
            return Database.Table<DataFormModel>().Where(i => i.Name == name).FirstOrDefaultAsync();
        }

        public Task<int> SaveItemAsync(DataFormModel item)
        {
            return Database.InsertAsync(item);
        }

        public Task<int> DeleteItemAsync(DataFormModel item)
        {
            return Database.DeleteAsync(item);
        }
    }
}